# Wich et al. Using drones to determine chimpanzee absence at the edge of their distribution in western Tanzania
library(unmarked)
library(MuMIn)
library(AICcmodavg)


# 1) Running N-mixture models using data from Bonnin et al. 2018 to estimate nest detection probability during a flight in a 50x500m plot depending on GSD

# Load detection matrix (from Bonnin et al. 2018, cells indicate numbers of nests detected during a drone survey)
data_presence <- read.csv("nmix_observation_matrix.csv", sep=";", header=TRUE)
data.y <- data_presence[,-1] 

# Load observation-level covariates (covariates affecting detection probability, in this case only GSD)
cov.det<- read.csv("covariate_matrix_GSD.csv", sep=";", header=TRUE)
obsCovs <- list(GSD=cov.det[,2:4])

# Create data frame to be used for running N-mixture models
data.umf <- unmarkedFramePCount (y=data.y, obsCovs = obsCovs)
summary(data.umf)

# create null and full model using a poisson distribution (abundance is assumed constant at all sites)
fm0 <- pcount (~1 ~1, data=data.umf)
fm1 <- pcount(~GSD ~1, data=data.umf)
# create null and full model using a negativ-binomial distribution (assumes nests to show a clumped distribution)
fm0NB <- pcount (~1 ~1, data=data.umf, mixture=c("NB")) 
fm1NB <- pcount (~GSD ~1, data=data.umf, mixture=c("NB"))

# run goodness of fit test for global detection models using either distribution:
chisq <- function(fm) {
  umf <- getData(fm)
  y <- getY(umf)
  y[y>1] <- 1
  sr <- fm@sitesRemoved
  if(length(sr)>0)
    y <- y[-sr,,drop=FALSE]
  fv <- fitted(fm, na.rm=TRUE)
  y[is.na(fv)] <- NA
  sum((y-fv)^2/(fv*(1-fv)), na.rm=TRUE)
}
(pb <- parboot(fm1, chisq, nsim=1000, report=1)) # p = 0.161, model fits
(pb <- parboot(fm1NB, chisq, nsim=1000, report=1)) # p = 0.579, model fits
# both full poisson and NB distribution fit the data (p > 0.05 indicates that modeled data are not different from observed data based on results from 1000 simulations)


# check whether Poisson or NB mode provides a more realistic abundance estimate (compared with ground data in Bonnin et al. 2018)
backTransform(fm1, type="state") # average nest abundance is 24.5 per site which is less than reported in Bonnin et al. 2018
backTransform(fm1NB, type="state") # average nest abundance is 39.6 per site which coincides with information reported in Bonnin et al. 2018

# check AICc 
AICc(fm1) # AICc = 173.98
AICc(fm1NB) # AICc = 162.98 -> NB model better suitable than Poisson model
AICc(fm0)# AICc = 198.25 -> delta AIC is larger than 7 (delta AIC = 35.27 compared to fm1NB), indicating that GSD is a valid predictor for detection probability

# choose NB model for further calculation:
detback <- linearComb(fm1NB,  c(0,4.280), type="det") # 4.280 is the average GSD used in Bonnin et al. 2018
backTransform(detback) # back-transformed nest detection probability is 0.196 at average GSD (SE = 0.0454)

# Predicting nest detection probability depending on GSD:
newdata <- data.frame(GSD=seq(1.46,5.86, length=480)) #predicting different values from minimum GSD and maximum GSD used during Wich et al. 2022 flights
Ep <- predict(fm1NB, type="det", newdata=newdata, appendData=TRUE)

# Graph for Figure 3 based on predicted values
library(ggplot2)
ggplot(data = Ep,
       aes(x = GSD,
           y = Predicted)) +
  geom_ribbon(aes(x=GSD, ymin=lower, ymax=upper), fill="gray80")+
  scale_y_continuous(limits = c(0, 0.4))+
  geom_point(color="steelblue", 
             size = 2, 
             alpha=.8) +
  xlim(2,6)+
  labs(x = "GSD",
       y = "Nest detection probability") +
  theme_classic(base_size=23)


write.csv(Ep,'Predictions.csv')




# 2) Use predicted data from Predictions.csv to calculate nest detection probability during flights from Wich et al. (reported in Table 2)


# 3) Predicting false-absence probabilities depending on GSD and number of surveyed plots 
Figure5 <- read.csv("Predictions_Figure5.csv", sep=";", header=TRUE) # based on predictions from Predictions.csv, extrapolated for varying plot numbers for minimum, median and maximum values of GSD

# Graph for Figure 5 based on predicted values from Predictions_Figure5
ggplot(data = Figure5,
       aes(x = Plots,
           y = FN_prob)) +
  geom_ribbon(aes(x=Plots, ymin=FN_lower, ymax=FN_upper), fill="gray80")+
  scale_y_continuous(limits = c(0, 0.5))+
  geom_point(color="steelblue", 
             size = 2, 
             alpha=.8) +
  xlim(0,150)+
  labs(x = "Number of surveyed plots",
       y = "False-absence probability") +
  theme_classic(base_size=23)+
  geom_hline(yintercept = 0.05, linetype = 2, color="red")+
  facet_grid(cols=vars(GSD))

